@@ -1,5 +1,6 @@
 from moviebotapi.core.session import Session
 from moviebotapi.douban import DoubanApi
+from moviebotapi.library import LibraryApi
 from moviebotapi.meta import MetaApi
 from moviebotapi.notify import NotifyApi
 from moviebotapi.scraper import ScraperApi
@@ -25,6 +26,7 @@ class MovieBotServer:
     meta: MetaApi
     common: CommonApi
     amr: AmrApi
+    library: LibraryApi
 
     def __init__(self, session: Session = None):
         if session:
@@ -43,3 +45,4 @@ class MovieBotServer:
         self.meta = MetaApi(session)
         self.common = CommonApi(session)
         self.amr = AmrApi(session)
+        self.library = LibraryApi(session)
